#
#
#		RNA Polymerase II Script
#		Loren Williams, Georgia Tech
#		
#		From 
#		Structural Basis of Transcription: Role of the Trigger Loop 
#       in Substrate Specificity and Catalysis
#		
#
#   Dong Wang 2
#    David A. Bushnell 2
#    Kenneth D. Westover
#    Craig D. Kaplan
#    Roger D. Kornberg
#
# DOI:https://doi.org/10.1016/j.cell.2006.11.023
# Structural Basis of Transcription: Role of the Trigger 
# Loop in Substrate Specificity and Catalysis

#-----------------------------------------------------------------------------
## Header: General Commands ##

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# run the python program for hydrogen bonding interactions.
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
## End of Header: General Commands ##
#----------------------------------------


reinitialize
bg_color white
set cartoon_ring_mode, 3


load files/2YU9.pdb, complex
hide everything, complex
show cartoon, complex

create template_DNA, chain T
hide everything, template_DNA,
show cartoon, template_DNA
color cyan, template_DNA
show stick, /template_DNA//T/DA`18/
#color wheat, name C* and dna*
label  /template_DNA//T/DT`28/O3', "DNA"


create non_template_DNA, chain N
hide everything, non_template_DNA,
show cartoon, non_template_DNA
color blue, non_template_DNA
show stick, /non_template_DNA//T/DA`18/* 

create RNA, chain R
hide everything, RNA
show cartoon, RNA
show stick, RNA
color red, RNA
label  /RNA//R/A`5/OP1, "RNA"

create A-site, /complex//A/UTP`2003/*`B
hide everything, A-site
show sticks, A-site
color orange, A-site
set valence, 0

create E-site, /complex//A/UTP`2003/*`A
hide everything, E-site
show sticks, E-site
color yellow, E-site

create magnesium, resn Mg and complex
show spheres, magnesium
color magenta, magnesium
alter magnesium, vdw=.6 
rebuild

create  Rpb1, chain A
color pink, Rpb1
create Rpb2, chain B
color cyan, Rpb2
set cartoon_transparency=0.6, Rpb*

create bridge_helix, Rpb1 and resi 815-844   
color green, bridge_helix

create trigger_loop, Rpb1 and resi 1080-1096
show stick, trigger_loop and resi 1085
color magenta, trigger_loop

distance dist_attack, /RNA//R/A`10/C3', A-site//A/UTP`2003/PA`B
distance dist_his_OP, /trigger_loop//A/HIS`1085/NE2, /A-site//A/UTP`2003/O2B`B
color black, dist_attack
color black, dist_his_OP
color red, resn his and resi 1085 and trigger_loop 

#delete complex

set cartoon_cylindrical_helices,2, Rpb*
set cartoon_cylindrical_helices,2, bridge_helix
disable Rpb*
disable complex

set_view (\
     0.429460317,   -0.778372943,   -0.457951993,\
     0.693623066,   -0.040445622,    0.719214976,\
    -0.578333437,   -0.626518905,    0.522522211,\
    -0.000957265,   -0.001844972, -268.772430420,\
    35.986381531,  -29.922462463,   63.891784668,\
   177.201019287,  360.377685547,  -20.000000000 )
### cut above here and paste into script ###
